---
title: Defining Nodes & Ports
id: defining-nodes-ports
---

How your node editor behaves depends on the configurations you provide for nodes and ports. These configurations are referred to as `nodeTypes` and `portTypes` respectively.

While you may write this configuration manually (it's just a JSON object), Flume gives you a configuration generator called `FlumeConfig` to make this process easier.

## A simple example

Before we get started with an example, let's take a look at the simple editor we'll be building.
